Beta <- function(shape1 = 1, shape2 = 2, ncp = 0) new("Beta", shape1 = shape1, shape2 = shape2, ncp = ncp)
Binom <- function(size = 1,prob = 0.5) new("Binom", size = size, prob = prob)
Cauchy <- function(location = 0, scale = 1) new("Cauchy", location = location, scale = scale)
Chisq <- function(df = 1, ncp = 0) new("Chisq", df = df, ncp = ncp)
Dirac <- function(location = 0) new("Dirac", location = location)
Exp <- function(rate = 1) new("Exp", rate = rate)
Fd <- function(df1 = 1, df2 = 1, ncp = 0) new("Fd", df1 = df1, df2 = df2, ncp = ncp)
Gammad <- function(shape = 1, scale = 1) new("Gammad", shape = shape, scale = scale)
Geom <- function(prob = 0.5) new("Geom", prob = prob)
Hyper <- function(m = 1, n = 1, k = 1) new("Hyper", m = m, n = n, k = k)
Logis <- function(location = 0, scale = 1) new("Logis", location = location, scale = scale)
Lnorm <- function(meanlog = 0, sdlog = 1) new("Lnorm", meanlog = meanlog, sdlog = sdlog)
Nbinom <- function(size = 1,prob = 0.5) new("Nbinom", size = size, prob = prob)
Norm <- function(mean = 0, sd = 1) new("Norm", mean = mean, sd = sd)
Pois <- function(lambda = 1) new("Pois", lambda = lambda)
Td <- function(df = 1, ncp = 0) new("Td", df = df, ncp = ncp)
Unif <- function(Min = 0, Max = 1) new("Unif", Min = Min, Max = Max)
Weibull <- function(shape = 1, scale = 1) new("Weibull", shape = shape, scale = scale)
